==> haskell-tagstream-conduit-0.5.6-102-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tagstream-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tagstream-conduit
version:              0.5.6
visibility:           public
id:                   tagstream-conduit-0.5.6-C9EdGyBlWLe7i7eFvkMa4s
key:                  tagstream-conduit-0.5.6-C9EdGyBlWLe7i7eFvkMa4s
license:              BSD-3-Clause
maintainer:           yi.codeplayer@gmail.com
author:               yihuang
homepage:             http://github.com/yihuang/tagstream-conduit
synopsis:             streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.

category:             Web, Conduit
abi:                  0dc72df04ae0ee3d5423012c3985c5f6
exposed:              True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Entities Text.HTML.TagStream.Text
    Text.HTML.TagStream.Types Text.HTML.TagStream.Utils

import-dirs:          /usr/lib/ghc-8.10.4/site-local/tagstream-conduit-0.5.6
library-dirs:         /usr/lib/ghc-8.10.4/site-local/tagstream-conduit-0.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/tagstream-conduit-0.5.6
hs-libraries:         HStagstream-conduit-0.5.6-C9EdGyBlWLe7i7eFvkMa4s
depends:
    attoparsec-0.13.2.5-FoDbMc7Lera4Wp4h1A8KKA base-4.14.1.0
    blaze-builder-0.4.2.1-KRXf5d4GbjLDdq3vlVdrGQ bytestring-0.10.12.0
    case-insensitive-1.2.1.0-7JftqYqo1mT4hjl6NnKcKA
    conduit-1.3.4-7hHdJ0hANSnEOhwHWEIEBh
    conduit-extra-1.3.5-1u7TtXzx4t94AF58b7yBdF
    data-default-0.7.1.1-JpqGMcmeSO6HucVgz21XKA
    resourcet-1.2.4.2-8VlJo6yN26lBlamTMjWrHN text-1.2.4.1
    transformers-0.5.6.2 xml-conduit-1.9.0.0-7vufa70o0Xm9kpD49tFwhq

haddock-interfaces:
    /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock

haddock-html:         /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tagstream-conduit-0.5.6-108-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tagstream-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tagstream-conduit
version:              0.5.6
visibility:           public
id:                   tagstream-conduit-0.5.6-IaepjgCiXPR2nPw5NJdKBj
key:                  tagstream-conduit-0.5.6-IaepjgCiXPR2nPw5NJdKBj
license:              BSD-3-Clause
maintainer:           yi.codeplayer@gmail.com
author:               yihuang
homepage:             http://github.com/yihuang/tagstream-conduit
synopsis:             streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.

category:             Web, Conduit
abi:                  f2e37431d6b880eeea73685e2b4bf6f8
exposed:              True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Entities Text.HTML.TagStream.Text
    Text.HTML.TagStream.Types Text.HTML.TagStream.Utils

import-dirs:          /usr/lib/ghc-8.10.4/site-local/tagstream-conduit-0.5.6
library-dirs:         /usr/lib/ghc-8.10.4/site-local/tagstream-conduit-0.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/tagstream-conduit-0.5.6
hs-libraries:         HStagstream-conduit-0.5.6-IaepjgCiXPR2nPw5NJdKBj
depends:
    attoparsec-0.13.2.5-7R4lnPSYFsgEphvzk6ZRzM base-4.14.1.0
    blaze-builder-0.4.2.1-KRXf5d4GbjLDdq3vlVdrGQ bytestring-0.10.12.0
    case-insensitive-1.2.1.0-L4eezPrloIkFfLdkfuDqXK
    conduit-1.3.4.1-EsXrTaG9JYTH3mYUndnZkh
    conduit-extra-1.3.5-BxFPoUVGhguJbqMXSmH17Y
    data-default-0.7.1.1-DVZWGRf90hqGebpGTaPvOV
    resourcet-1.2.4.2-HAfwAGu4bbRDn6PUO3bzf2 text-1.2.4.1
    transformers-0.5.6.2 xml-conduit-1.9.1.0-Ix7XCWPJ7GCDdn96w9bpXg

haddock-interfaces:
    /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock

haddock-html:         /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
